@@ -10,12 +10,12 @@
 
 #include "askwidget.h"
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
-#include <qapplication.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QApplication>
+#include <QLabel>
+#include <QLayout>
 
 #include "map.h"
 
@@ -81,10 +81,14 @@ void askWidget::nextQuestion()
 	QString aux;
 	if (p_asked.count() < p_count)
 	{
-		aux = p_map -> getRandomDivision(askMode());
-		while (p_asked.indexOf(aux) != -1) aux = p_map -> getRandomDivision(askMode());
+		division *div;
+		do
+		{
+			div = p_map -> getRandomDivision(askMode());
+			aux = div -> getUntranslatedName();
+		} while (p_asked.indexOf(aux) != -1);
 		p_asked << aux;
-		nextQuestionHook(aux);
+		nextQuestionHook(div);
 	}
 	else emit questionsEnded();
 }
