@@ -10,21 +10,21 @@
 
 #include "kgeography.h"
 
-#include <kconfigdialog.h>
-#include <kmessagebox.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <ktoolbar.h>
-#include <kactioncollection.h>
-#include <klocalizedstring.h>
+#include <KConfigDialog>
+#include <KMessageBox>
+#include <KStandardAction>
+#include <KToggleAction>
+#include <KToolBar>
+#include <KActionCollection>
+#include <KLocalizedString>
 
-#include <qmenubar.h>
-#include <qfile.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qsize.h>
-#include <qtimer.h>
-#include <qpushbutton.h>
+#include <QMenuBar>
+#include <QFile>
+#include <QLabel>
+#include <QLayout>
+#include <QSize>
+#include <QTimer>
+#include <QPushButton>
 
 #include "answersdialog.h"
 #include "capitaldivisionasker.h"
@@ -416,13 +416,13 @@ void kgeography::setMap(KGmap *m)
 	p_map = m;
 	p_showAuthor->setEnabled(m);
 
-	QString mapName = i18nc(p_map -> getFileName().toUtf8(), p_map -> getName().toUtf8());
-	QString divisionType = i18nc(p_map -> getFileName().toUtf8(), p_map->getDivisionsString().toUtf8());
+	QString mapName = p_map -> getName();
+	QString divisionType = p_map->getDivisionsString();
 
 	p_askMap->setText(i18n("&Location of %1", divisionType));
 	p_askPlaceMap->setText(i18n("&Place %1 in the Map", divisionType));
-	p_askCapitalDivisions->setText(i18nc("@title", p_map->getCapitalToDivisionTitle().toUtf8()));
-	p_askDivisionCapitals->setText(i18nc("@title", p_map->getDivisionToCapitalTitle().toUtf8()));
+	p_askCapitalDivisions->setText(p_map->getCapitalToDivisionTitle());
+	p_askDivisionCapitals->setText(p_map->getDivisionToCapitalTitle());
 	p_askFlagDivisions->setText(i18n("%1 by Flag", divisionType));
 	p_askDivisionFlags->setText(i18n("&Flags of %1", divisionType));
 
