@@ -10,14 +10,16 @@
 
 #include "mypopup.h"
 
-#include <kiconloader.h>
-#include <klocalizedstring.h>
+#include <KIconLoader>
+#include <KLocalizedString>
 
-#include <qevent.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qimage.h>
-#include <qdesktopservices.h>
+#include <QEvent>
+#include <QIcon>
+#include <QLabel>
+#include <QLayout>
+#include <QImage>
+#include <QDesktopServices>
+#include <QUrl>
 
 myPopup::myPopup(QWidget *parent, const QString &text, const QString &wikiLink, const QString &text2, const QString &flagFile) : QFrame(parent, Qt::FramelessWindowHint)
 {
@@ -30,7 +32,7 @@ myPopup::myPopup(QWidget *parent, const QString &text, const QString &wikiLink,
 	{
 		wiki = new QLabel(this);
 		lay -> addWidget(wiki);
-		wiki -> setPixmap(SmallIcon( QStringLiteral("dialog-information") ));
+		wiki -> setPixmap(QIcon::fromTheme( QStringLiteral("dialog-information") ).pixmap(KIconLoader::SizeSmall));
 		wiki -> setToolTip(i18n("Wikipedia page"));
 		wiki -> setAlignment(Qt::AlignCenter);
 		wiki -> installEventFilter(this);
